# Copyright (c) Meta Platforms, Inc. and affiliates.
# All rights reserved.
#
# This source code is licensed under the BSD-style license found in the
# LICENSE file in the root directory of this source tree.

#' @include PrestoResult.R
NULL

.dbHasCompleted <- function(res, ...) {
  return(res@query$hasCompleted())
}

#' @rdname PrestoResult-class
#' @importMethodsFrom DBI dbHasCompleted
#' @export
setMethod("dbHasCompleted", "PrestoResult", .dbHasCompleted)
